[Website](https://www.cortex.dev) • [Slack](https://community.cortex.dev) • [Docs](https://docs.cortex.dev)

<br>

<img src='https://s3-us-west-2.amazonaws.com/cortex-public/logo.png' height='42'>

<br>

# Scale compute-intensive serverless workloads

One platform for all your microservices, data processing, and machine learning workloads.

<br>

## Forget about resource limits, cold starts, and timeouts

* **No resource limits** - allocate as much CPU, GPU, and memory as each workload requires.
* **No cold starts** - keep a minimum number of API replicas running to ensure that requests are handled in real-time.
* **No timeouts** - run workloads for as long as you want.

<br>

## Run realtime, batch, and async workloads

* **Realtime** - realtime APIs respond to requests in real-time and autoscale based on in-flight request volumes.
* **Batch** - batch APIs run distributed and fault-tolerant batch processing jobs on-demand.
* **Async** - async APIs process requests asynchronously and autoscale based on request queue length.

<br>

## Minimize costs, especially at scale

* **Spot instance management** - cortex can automatically run your workloads on spot instances so that you can save money without sacrificing reliability.
* **Customizable autoscaling** - optimize the autoscaling behavior for each workload to ensure efficient resource utilization.

<br>

## Streamline your development workflow

* **Deploy functions and containers** - upload Python functions and let Cortex manage dependencies or connect to your image registry.
* **Deploy programmatically** - deploy your code interactively with a CLI or programmatically with a Python client.
* **Debug locally** - keep your local and cloud workflows similar so that you can iterate on your code faster.

<br>

## Integrate with modern observability tools

* **Stream structured logs** - automatically stream logs from every workload to your favorite log management tool.
* **Collect custom metrics** - monitor your workloads with pre-built dashboards and add your own custom dashboards.

<br>

## Deploy Cortex on your AWS account

* **Identity & Access Management** - Cortex integrates with IAM to simplify authentication and authorization worklfows.
* **Elastic Kubernetes Service** - Cortex runs on top of EKS to scale workloads reliably and cost-effectively.
* **Billing & Cost Management** - Cortex supports resource tagging to enable detailed spend visibility.
